@@ -16,7 +16,15 @@ function update(){
             if(json.exceptionStatus == "1"){ //exception occured
                 showException(json.exceptionTitle,json.exceptionBody)
             }
-            
+            /*
+            if(json.threadRunning == "1"){ //Thread is running, display loading
+                showLoading()
+                console.log('thread is Running')
+            }
+            if(json.threadRunning != "1"){
+                hideLoading()
+            }
+            */
             
             //set player buttons
             if (json.playerStatus == "0"){ //stopped, disable all buttons
@@ -54,6 +62,14 @@ function clearException(){
     window.location = './clearException';
 }
 
+function showLoading(){
+    $("#loading").show();
+}
+
+function hideLoading(){
+    $("#loading").hide();
+}
+
 function searchFile(){
     window.location = './searchFile?search=' + $("#browserSearch").val();
 }
